@@ -1,5 +1,5 @@
 /* This file is part of GNU Rush.                  
-   Copyright (C) 2008, 2009 Sergey Poznyakoff
+   Copyright (C) 2008, 2009, 2010 Sergey Poznyakoff
 
    GNU Rush is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -68,7 +68,9 @@ enum rushdb_result {
 	rushdb_result_fail
 };
 
-extern int rush_wtmp_mode;
+extern mode_t rushdb_umask;
+extern mode_t rushdb_dir_mode;
+extern mode_t rushdb_file_mode;
 
 enum rush_wtmp_dir {
 	rush_wtmp_forward,
