@@ -1,5 +1,5 @@
 /* This file is part of GNU Rush.                  
-   Copyright (C) 2008, 2009 Sergey Poznyakoff
+   Copyright (C) 2008, 2009, 2010 Sergey Poznyakoff
 
    GNU Rush is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -31,14 +31,13 @@
 enum rush_wtmp_dir rush_wtmp_dir = rush_wtmp_forward;
 static int wtmp_fd = -1;
 static size_t wtmp_recsize = 0;
-int rush_wtmp_mode = 0660;
 
 int
 rush_wtmp_open(const char *name, int rw)
 {
 	int fd;
 	
-	fd = open(name, rw ? O_RDWR|O_CREAT : O_RDONLY, rush_wtmp_mode);
+	fd = open(name, rw ? O_RDWR|O_CREAT : O_RDONLY, rushdb_file_mode);
 	if (fd == -1)
 		return -1;
 	wtmp_fd = fd;
